@@ -43,8 +43,11 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
             field_name = item['field_name']
             action = item['action']
             if action == 'text_to_choice':
-                datalists.append((field_name, Obj.objects.filter().values_list(\
-                        field_name, flat=True).distinct().order_by(field_name)))
+                if 'queryset' in item:
+                    datalists.append(item['queryset'])
+                else:
+                    datalists.append((field_name, Obj.objects.filter().values_list(\
+                            field_name, flat=True).distinct().order_by(field_name)))
                 field_updates.append((field_name, 'list', field_name))
         if datalists:
             ret_dic['datalists'] = datalists
@@ -61,14 +64,16 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
                 else:
                     return HttpResponseRedirect(reverse("%ss" % \
                             ret_dic['class_name'].lower()))
-        form = ObjForm(request.POST, request=request)
+        form = apply_translations(ObjForm(request.POST, request=request), \
+                translations)
         if callback_prevalidation:
             form = callback_prevalidation(form)
         if form.is_valid():
             if callback_postvalidation:
                 form = callback_postvalidation(form)
                 if not form.is_valid():
-                    ret_dic['form'] = ObjForm(request.POST, request=request)
+                    ret_dic['form'] = apply_translations(\
+                            ObjForm(request.POST, request=request), translations)
                     request.session['err'] = []
                     for field, msg in form._errors.items():
                         request.session['err'].append('%s: %s' % (field, ' | '.join(msg)))
@@ -83,7 +88,7 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
             except AttributeError:
                 pass
             if callback_postsaveaction:
-                obj = callback_postsaveaction(obj)
+                obj = callback_postsaveaction(obj, form, request)
                 #TBF - it' s an ugly solution.
                 #Hint: http://stackoverflow.com/questions/11137309/django-is-it-possible-to-make-a-redirect-from-a-function-in-a-view
                 if type(obj) == HttpResponseRedirect:
@@ -94,17 +99,16 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
             return HttpResponseRedirect(reverse(ret_dic['class_name'].lower(), \
                     args=(obj.id,)))
         else:
-            ret_dic['form'] = apply_translations(\
-                    ObjForm(request.POST, request=request), translations)
-            ret_dic['form'] = apply_field_updates(\
-                    ObjForm(request.POST, request=request), field_updates)
+            ret_dic['form'] = apply_field_updates(
+                    apply_translations(\
+                    ObjForm(request.POST, request=request), translations), \
+                    field_updates)
             return render(request, 'generalobj_new.html', \
                     ret_dic)
     else:
-        ret_dic['form'] = apply_translations(ObjForm(request=request), \
-                translations)
-        ret_dic['form'] = apply_field_updates(ObjForm(request=request), \
-                field_updates)
+        ret_dic['form'] = apply_field_updates(
+                apply_translations(ObjForm(request=request), \
+                translations), field_updates)
         return render(request, 'generalobj_new.html', ret_dic)
 
     return HttpResponse('qqq')
@@ -434,6 +438,8 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         ret_dic['ajax_url'] = ajax_url
     if 'passing_scripts' in kwargs:
         ret_dic['passing_scripts'] = kwargs['passing_scripts']
+    if 'passing_scriptsready' in kwargs:
+        ret_dic['passing_scriptsready'] = kwargs['passing_scriptsready']
     ret_dic['url_new'] = reverse('%s_new' % ret_dic['class_name'].lower())
     ret_dic['allow_prompt_ajax_search'] = allow_prompt_ajax_search
     ret_dic['allow_overall_search'] = allow_overall_search
